package gui.panels;

import gui.states.MousePosState;

import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.io.File;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;

import javax.imageio.ImageIO;
import javax.swing.*;

public class RemoteControlPanel extends JPanel {
	private static final String MainBGImage = "remote.png";
	
	private final Image myBackgroundImage;
	private final List<MousePosState> myMouseStates;
	
	public RemoteControlPanel(List<MousePosState> remoteStates) throws IOException {
		myBackgroundImage = ImageIO.read(new File("media/images/remote", MainBGImage));
		myMouseStates = new LinkedList<MousePosState>(remoteStates);
		
		setPreferredSize(new Dimension(361, 200));
		setMinimumSize(getPreferredSize());
		setMaximumSize(getPreferredSize());
		
		MousePosListener positionAdapter = new MousePosListener();
		addMouseListener(positionAdapter);
		addMouseMotionListener(positionAdapter);
	}

	public void paint(Graphics g) {
		g.drawImage(myBackgroundImage, 0, 0, 361, 200, null);
	}

	private class MousePosListener extends MouseAdapter implements
			MouseMotionListener {

		public void mouseClicked(MouseEvent e) {
			for (MousePosState state : myMouseStates) {
				if (state.isActiveOver(e.getPoint())) {
					state.react();
				}
			}			
		}

		public void mouseMoved(MouseEvent e) {
			setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
			for (MousePosState state : myMouseStates) {
				if (state.isActiveOver(e.getPoint())) {
					setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
				}
			}
		}

		public void mouseDragged(MouseEvent e) {
			// Just to be compatible with Java 1.5
		}
	}
}
