package gui.states;

import gui.panels.MouseAreaWatcher;

import javax.imageio.ImageIO;

import java.awt.*;
import java.io.File;
import java.io.IOException;

public class MousePosState implements IState {
	private final MouseAreaWatcher myWatcher;

	private final Point myTopLeftToDraw;
	private Image image;
	private Image imageBgClone;
	private final boolean isDoor;
	private final boolean isDrawable;
	private final boolean isReactable;
	private boolean isActivated = false;

	/* package-local */MousePosState(Point imageLeftTop, String imageName)
			throws IOException {
		this(imageLeftTop, imageName, null);
	}

	/* package-local */MousePosState(MouseAreaWatcher areaWatcher)
			throws IOException {
		this(null, "", areaWatcher);
	}

	/* package-local */MousePosState(Point imageLeftTop, String imageName,
			MouseAreaWatcher areaWatcher) throws IOException {
		myWatcher = areaWatcher; // may be null!
		isReactable = (myWatcher != null);
		myTopLeftToDraw = imageLeftTop; // may be null!
		isDrawable = (imageName != "");
		if (isDrawable) {
			image = ImageIO.read(new File("media/images", imageName));
			imageBgClone = ImageIO.read(new File("media/images/back_clones/" + imageName));
			image = Transparency.makeColorTransparent(image, new Color(200, 20, 200));
			imageBgClone = Transparency.makeColorTransparent(imageBgClone, new Color(200, 20, 200));
			System.out.println(imageName);
		}
		isDoor = imageName.contains("Door");
	}

	public final boolean isActiveOver(Point point) {
		return myWatcher.isPointOver(point);
	}

	public final boolean isDoor() {
		return isDoor;
	}

	public final boolean isActivated() {
		return isActivated;
	}

	public final void react() {
		isActivated = !isActivated;
		if (isReactable) {
			myWatcher.react();
		}
	}

	public final void drawImage(Graphics g) {
		if (!isDrawable) {
			System.err.println("Trying to draw non-drawable area!");
			return;
		}
		if (isActivated) {
			g.drawImage(image, myTopLeftToDraw.x, myTopLeftToDraw.y, image
					.getWidth(null), image.getHeight(null), null);
		} else {
			g.drawImage(imageBgClone, myTopLeftToDraw.x, myTopLeftToDraw.y,
					imageBgClone.getWidth(null), imageBgClone.getHeight(null),
					null);
		}
	}

	public final void animate(Graphics g) {
		if (!isDrawable) {
			System.err.println("Trying to animate non-drawable area!");
			return;
		}
		float x = 0.0f;
		float alpha;
		for (int i = 0; i < 50; i++) {
			int rule = AlphaComposite.SRC_OVER;
			alpha = x * x;
			x += 0.02f;
			Graphics2D g2 = (Graphics2D) g;
			if (g2 == null) {
				return;
			}
			g2.setComposite(AlphaComposite.getInstance(rule, alpha));
			drawImage(g);
			try {
				Thread.sleep(8);
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	}
}