package gui.states;

import car.ICar;

import gui.panels.MouseAreaWatcher;

import java.awt.*;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import remote.IRemoteControl;

import main.IReactable;

public class StatesFactory {

	private final IRemoteControl myRemote;
	private final ICar myCar;

	private final MouseAreaWatcher myFrontDoor = new MouseAreaWatcher(
			new Point(500, 235), new Point(600, 295), new IReactable() {
				private boolean isActivated = false;

				public void react() {
					isActivated = !isActivated;
					myCar.setFrontDoorState(isActivated);
				}
			});

	private final MouseAreaWatcher myRearDoor = new MouseAreaWatcher(new Point(
			585, 200), new Point(655, 260), new IReactable() {
		private boolean isActivated = false;

		public void react() {
			isActivated = !isActivated;
			myCar.setRearDoorState(isActivated);
		}
	});

	private final MouseAreaWatcher myHood = new MouseAreaWatcher(new Point(50,
			230), new Point(365, 335), new IReactable() {
		private boolean isActivated = false;

		public void react() {
			isActivated = !isActivated;
			myCar.setHoodState(isActivated);
		}
	});
	private final MouseAreaWatcher myBoot = new MouseAreaWatcher(new Point(550,
			120), new Point(675, 185), new IReactable() {
		private boolean isActivated = false;

		public void react() {
			isActivated = !isActivated;
			myCar.setBootState(isActivated);
		}
	});

	private final MouseAreaWatcher myFirstButton = new MouseAreaWatcher(
			new Point(193, 47), new Point(255, 175), new IReactable() {
				public void react() {
					myRemote.pressButton1();
				}
			});
	private final MouseAreaWatcher mySecondButton = new MouseAreaWatcher(
			new Point(44, 59), new Point(101, 168), new IReactable() {
				public void react() {
					myRemote.pressButton2();
				}
			});
	private final MouseAreaWatcher myThirdButton = new MouseAreaWatcher(
			new Point(118, 53), new Point(178, 175), new IReactable() {
				public void react() {
					myRemote.pressButton3();
				}
			});
	
	public StatesFactory(ICar car, IRemoteControl remote) {
		myCar = car;
		myRemote = remote;
	}

	public List<MousePosState> getCarStates() throws IOException {
		MousePosState rearDoorState = new MousePosState(new Point(553, 137),
				"rearDoor.png", myRearDoor);
		MousePosState frontDoorState = new MousePosState(new Point(489, 125),
				"frontDoor.png", myFrontDoor);
		MousePosState bootState = new MousePosState(new Point(462, 0),
				"boot.png", myBoot);
		MousePosState hoodState = new MousePosState(new Point(0, 0),
				"hood.png", myHood);
		return Collections.unmodifiableList(Arrays.asList(bootState, rearDoorState,
				frontDoorState, hoodState));
	}

	public List<MousePosState> getRemoteStates() throws IOException {
		MousePosState firstButton = new MousePosState(myFirstButton);
		MousePosState secondButton = new MousePosState(mySecondButton);
		MousePosState thirdButton = new MousePosState(myThirdButton);
		return Collections.unmodifiableList(Arrays.asList(firstButton,
				secondButton, thirdButton));
	}
	
	public MousePosState getBlinkingLampState() throws IOException {
		return new MousePosState(new Point(157, 328), "leadLamp.png");
	}
}