package siren;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import javazoom.jl.decoder.JavaLayerException;
import javazoom.jl.player.Player;

public class Siren {

	private final static String BEEP1 = "media/sounds/oneBeep.mp3";
	private final static String BEEP2 = "media/sounds/twoBeeps.mp3";
	private final static String BEEP3 = "media/sounds/threeBeeps.mp3";
	private final static String BEEP4 = "media/sounds/fourBeeps.mp3";
	private final static String ALARM = "media/sounds/alarm.mp3";
	private final static String DING = "media/sounds/ding.mp3";

	private static boolean lastWasAlarm = false;

	private static PlayerThread myPlayerThread;

	public static void ding() {
		if (lastWasAlarm && myPlayerThread.isAlive()) {
			return;
		}
		new PlayerThread(DING, 1).start();
	}

	public static void alarm(int amount) {
		if (lastWasAlarm && myPlayerThread.isAlive()) {
			myPlayerThread.incCounter(amount);
			return;
		}
		lastWasAlarm = true;
		if (myPlayerThread != null) {
			myPlayerThread.stopPlaying();
		}
		myPlayerThread = new PlayerThread(ALARM, amount);
		myPlayerThread.start();
	}

	public static void beep(int times) {
		if ((times < 1) || (times > 4)) {
			return;
		}
		if (myPlayerThread != null) {
			myPlayerThread.stopPlaying();
		}
		switch (times) {
		case 1:
			myPlayerThread = new PlayerThread(BEEP1, 1);
			break;
		case 2:
			myPlayerThread = new PlayerThread(BEEP2, 1);
			break;
		case 3:
			myPlayerThread = new PlayerThread(BEEP3, 1);
			break;
		case 4:
			myPlayerThread = new PlayerThread(BEEP4, 1);
			break;
		}

		new Thread(myPlayerThread).start();

	}

	private static class PlayerThread extends Thread {

		private Player myPlayer;
		private InputStream myInput;
		private final String myFileName;
		private int myCounter;

		public PlayerThread(String fileName, int amount) {
			myFileName = fileName;
			myCounter = amount;
		}

		public void incCounter(int amount) {
			if (amount > myCounter) {
				myCounter = amount;
			}
		}

		public void run() {
			while (myCounter > 0) {
				resetInput();
				try {
					myPlayer.play();
					myCounter--;
				} catch (JavaLayerException e) {
					System.out.println("Error while playing " + e);
					return;
				}
			}
		}

		private void resetInput() {
			try {
				myInput = new FileInputStream(myFileName);
				myPlayer = new Player(myInput);
			} catch (IOException e) {
				System.out.println("File not found " + e);
			} catch (JavaLayerException e) {
				System.out.println("Unable to play file " + e);
			}
		}

		public void stopPlaying() {
			myCounter = 0;
			myPlayer.close();
		}
	}
}